@@ -6,7 +6,7 @@ from syst3m.classes.color import color
 # input.
 _input_ = input
 def input(message, yes_no=False):
-	if len(message) > 0 and message[0].upper() != message[0]: message = Formats.String(message).capitalized_word()
+	if len(message) > 0 and message[0].upper() != message[0]: message = String(message).capitalized_word()
 	msg = color.fill(message)
 	if yes_no:
 		while True:
@@ -27,46 +27,119 @@ def input(message, yes_no=False):
 
 # execute.
 def execute(
-	# the command in str format.
+	# option 1:
+	# the command in str format (str is saved to a script & then executed).
 	command="ls .",
 	# joiner for when command is in list format.
 	joiner="\n",
-	# serialize to dict. (r3sponse.ResponseObject) (slice first dict).
-	serialize=False,
+	# option 2:
+	path=None,
 	# the executive.
 	executive="sh",
+	# the arguments passed to the script.
+	arguments=[], 
+	# the subprocess shell parameter.
+	shell=False,
+	# serialize to dict.
+	# aka expect dict format.
+	serialize=False,
 ):
-	path = f"/tmp/tmp_script_{Formats.String('').generate()}"
-	if isinstance(command, list):
-		command = Files.Array(array=command).string(joiner=joiner)
-	Files.save(path, command)
+	
+	# output class.
+	class Output(ResponseObject):
+		def __init__(self, 
+			# the success message (param #1).
+			message=None,
+			# the attributes (param #2).
+			attributes={},
+			# the error message (param #3).
+			error=None,
+		):
+			dictionary = {
+				"success":error == None,
+				"message":message,
+				"error":error,
+			}
+			for key,value in attributes.items():
+				dictionary[key] = value
+			ResponseObject.__init__(self, dictionary)
+			if self.success:
+				self.str = self["output"]
+			else:
+				self.str = self.error
+		def __str__(self):
+			return str(self.str)
+		# support default iteration.
+		def __iter__(self):
+			return iter(str(self))
+		# support '==' & '!=' operator.
+		def __eq__(self, string):
+			if not isinstance(string, str):
+				return False
+			return self.str == string
+		def __ne__(self, string):
+			if not isinstance(string, str):
+				return True
+			return self.str != string
+		# support 'in' operator.
+		def __contains__(self, string):
+			if isinstance(path, (list, Array)):
+				for i in string:
+					if i in self.str:
+						return True
+				return False
+			else:
+				return string in self.str
+			#
+		# object instance.
+		def instance(self):
+			return "Output"
+			#
+
+	# excute.
+	delete = False
+	if path == None:
+		delete = True
+		path = f"/tmp/tmp_script_{String('').generate()}"
+		if isinstance(command, list):
+			command = Array(array=command).string(joiner=joiner)
+		Files.save(path, command)
+		response_str = f"command ({command})"
+	else:
+		response_str = f"script ({path})"
 	try:
 		proc = subprocess.run(
-		    [executive, path],
+			[executive, path] + arguments,
 			check=True,
 			capture_output=True,
 			text=True,
+			shell=shell,
 		)
 	except subprocess.CalledProcessError as error:
+		exception = String(str(error))
+		if "Command '[" in exception:
+			to_replace = f"'{exception.slice_array()}'"
+			exception = exception.replace(str(to_replace), "[ ... ]")
 		error_, output = error.stderr, error.output
 		if isinstance(error_, bytes): error_ = error_.decode()
-		if isinstance(output, bytes): output = error_.decode()
-		return r3sponse.error(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+		if isinstance(output, bytes): output = output.decode()
+		return Output(error=f"Failed to execute {response_str}, (exception: {exception}), (output: {output}), (error: {error_}).")
 	error_, output = proc.stderr, proc.stdout
 	if isinstance(error_, bytes): error_ = error_.decode()
-	if isinstance(output, bytes): output = error_.decode()
+	if isinstance(output, bytes): output = output.decode()
 	if error_ != "":
-		return r3sponse.error(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+		return Output(error=f"Failed to execute {response_str}, (output: {output}), (error: {error_}).")
 	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
-	Files.delete(path)
+	if delete:
+		Files.delete(path)
 	if serialize:
 		try: response = r3sponse.ResponseObject(json=output)
 		except Exception as e: 
 			if loader != None: loader.stop(success=False)
-			return r3sponse.error(f"Failed to serialize output: {output}")
+			return Output(error=f"Failed to serialize output: {output}")
 		return response
 	else:
-		return r3sponse.success(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
+		return Output(message=f"Succesfully executed {response_str}, (output: {output}), (error: {error_}).", attributes={
 			"output":output,
 			"process":proc,
 			#"pid":proc.pid, # only for subprocess.Popen
@@ -168,7 +241,7 @@ class Loader(threading.Thread):
 		if message[-len(" ..."):] == " ...": message = message[:-4]
 		if message[-len("."):] == ".": message = message[:-1]
 		if message[0].upper() != message[0]: message = message[1:]+message[0].upper()+message[1:]
-		return message
+		return color.fill(message)
 	def __empty_message__(self, length=len("hello world")):
 		s = ""
 		for i in range(length): s += " "
@@ -182,6 +255,7 @@ class ProgressLoader(threading.Thread):
 		if self.message[-len(" ..."):] == " ...": self.message = self.message[:-4]
 		if self.message[-len("."):] == ".": self.message = self.message[:-1]
 		if self.message[0].upper() != self.message[0]: self.message = self.message[1:]+self.message[0].upper()+self.message[1:]
+		self.message = color.fill(self.message)
 		self.index = index
 		self.max = max
 		self.progress = None
