@@ -38,7 +38,7 @@ class User(object):
 			return response
 
 		# check home dir.
-		if os.path.exists(self.home_directory): 
+		if Files.exists(self.home_directory): 
 			response["error"] = f"Home directory [{self.home_directory}] already exists."
 			return response
 
@@ -56,7 +56,7 @@ class User(object):
 				return response
 
 			else:
-				response["error"] = Formats.String(output.replace("useradd: ", "").replace("\n", ". ")).capitalized_word()
+				response["error"] = String(output.replace("useradd: ", "").replace("\n", ". ")).capitalized_word()
 				return response
 
 		# handle macos.
@@ -261,7 +261,7 @@ class Group(object):
 				return response
 
 			else:
-				response["error"] = Formats.String(output.replace("groupadd: ", "").replace("\n", ". ")).capitalized_word()
+				response["error"] = String(output.replace("groupadd: ", "").replace("\n", ". ")).capitalized_word()
 				return response
 
 		# handle macos.
@@ -382,7 +382,7 @@ class Group(object):
 				output = utils.__execute__(
 					command=["sudo", "deluser", user, self.name],)
 				if output != "":
-					response["error"] = Formats.String(output.replace("deluser: ", "").replace("\n", ". ")).capitalized_word()
+					response["error"] = String(output.replace("deluser: ", "").replace("\n", ". ")).capitalized_word()
 					return response
 
 		# handle macos.
@@ -415,7 +415,7 @@ class Group(object):
 				output = utils.__execute__(
 					command=["sudo", "usermod", "-a", "-G", self.name, user],)
 				if output != "":
-					response["error"] = Formats.String(output.replace("usermod: ", "").replace("\n", ". ")).capitalized_word()
+					response["error"] = String(output.replace("usermod: ", "").replace("\n", ". ")).capitalized_word()
 					return response
 
 		# handle macos.
